@@ -16,6 +16,7 @@ log_.message('Starting PyNeb version %s' % __version__, calling='PyNeb')
 
 if sys.version_info[0:2] < (2, 6):
     log_.warn('Python version >= 2.6 needed, seems you have {0}'.format(sys.version_info), calling='PyNeb')
+
 try:
     from numpy.version import version as numpy_version    
     if [int(n) for n in (numpy_version.split('.')[:3])] < [1, 5, 1] :
@@ -26,11 +27,12 @@ except:
 from .utils.manage_atomic_data import _ManageAtomicData
 atomicData = _ManageAtomicData()
 
-atomicData.defaultDict = 'PYNEB_20_01'
+atomicData.defaultDict = 'PYNEB_21_01'
 atomicData.resetDataFileDict()
 
 from .core.pynebcore import Atom, RecAtom, getAtomDict, getRecEmissivity, EmissionLine, Observation, \
     parseLineLabel, isValid
+#from .core.pipeline import PipeLine
 from .core.icf import ICF 
 from .core.diags import Diagnostics, diags_dict
 from .core.emisGrid import EmisGrid, getEmisGridDict
@@ -38,7 +40,7 @@ from .core.continuum import Continuum
 from .plot.plotAtomicData import DataPlot
 from .utils.physics import CST, print_IPs
 from .utils.saverestore import save, restore
-from .utils.init import LINE_LABEL_LIST, BLEND_LIST
+from .utils.init import LINE_LABEL_LIST, BLEND_LIST, label2levelDict
 from .utils.manage_atomic_data import getLevelsNIST
 from .utils.misc import ROOT_DIR
 from .extinction.red_corr import RedCorr
