@@ -262,20 +262,23 @@ IP["Hs"] = [7.6, 18.2, 29.3, 37.7, 51.2, 64.0, 78.0, 92.0, 160.0, 173.9, 206.1,
 IP["Mt"] = [50.0, 94.0, 109.0, 187.0, 202.0, 235.9, 257.0, 289.0, 318.0, 346.0, 386.0, 406.0, 445.0, 1035.0, 1072.0, 1112.0, 1154.0, 1195.0, 1234.0, 1311.0, 1352.0, 1397.0, 1439.0, 4464.0, 4551.0, 4640.0, 4740.0, 4830.0, 4920.0, 5160.0, 5250.0, 5360.0, 5450.0, 5840.0, 5930.0, 6030.0, 6130.0, 7040.0, 7150.0, 7440.0, 7550.0, 11460.0, 11660.0, 11870.0, 12100.0, 12320.0, 12530.0, 13200.0, 13400.0, 13700.0, 13900.0, 14500.0, 14700.0, 14900.0, 15100.0, 17900.0, 18200.0, 18700.0, 18900.0, 36700.0, 37200.0, 37800.0, 38300.0, 48500.0, 49400.0, 50300.0, 199606.0]
 IP["Ds"] = [65.0, 112.9, 128.0, 216.0, 231.0, 266.0, 288.0, 322.0, 352.0, 380.0, 422.0, 442.0, 483.0, 1087.0, 1125.0, 1165.0, 1208.0, 1250.0, 1290.0, 1369.0, 1412.0, 1457.0, 1500.0, 4590.0, 4680.0, 4770.0, 4870.0, 4960.0, 5060.0, 5300.0, 5400.0, 5500.0, 5600.0, 5990.0, 6080.0, 6190.0, 6280.0, 7230.0, 7350.0, 7640.0, 7750.0, 11730.0, 11930.0, 12140.0, 12380.0, 12600.0, 12810.0, 13500.0, 13700.0, 14000.0, 14200.0, 14800.0, 15000.0, 15300.0, 15500.0, 18400.0, 18600.0, 19100.0, 19400.0, 37400.0, 37900.0, 38500.0, 39100.0, 49800.0, 50700.0, 51600.0, 204400.0]
 
+
 IP_tmp = IP.copy()
 
 for elem in IP_tmp:
     IP[elem+'1'] = 0.0
     for ion, ip in enumerate(IP[elem]):
         IP['{}{}'.format(elem,ion+2)] = ip
+    for ion, ip in enumerate(IP[elem]):
+        IP['{}{}r'.format(elem,ion+1)] = ip
 
 IP['H2'] = 13.59844
-IP['He1'] = 0.0
-IP['He2'] = 24.58741
-IP['He3'] = 54.41778
-IP['H1r'] = 13.59844
-IP['He1r'] = 24.58741
-IP['He2r'] = 54.41778
+#IP['He1'] = 0.0
+#IP['He2'] = 24.58741
+#IP['He3'] = 54.41778
+#IP['H1r'] = 13.59844
+#IP['He1r'] = 24.58741
+#IP['He2r'] = 54.41778
 
 sym2name = {
             'H': 'hydrogen',
