@@ -9,7 +9,7 @@ if pn.config.Chianti_version_main == '8':
     from . import _chianti_tools_8 as _chianti_tools
 elif pn.config.Chianti_version_main == '7':
     from . import _chianti_tools
-elif pn.config.Chianti_version_main == '9':
+elif pn.config.Chianti_version_main in ('9', '10'):
     from . import _chianti_tools_9 as _chianti_tools
 from . import _chianti_constants as const
 from .physics import sym2name, vactoair
@@ -144,9 +144,7 @@ def Chianti_getOmega(ion_chianti, tem, lev1=None, lev2=None, Splups=None, NLevel
     pn.log_.debug('NLevels = {}'.format(NLevels), calling='Chianti_getOmega')
     temp=np.asarray(tem)
     if Splups is None:
-        if pn.config.Chianti_version_main == '9':
-            Splups = _chianti_tools.scupsRead(ion_chianti)
-        elif pn.config.Chianti_version_main == '8':
+        if pn.config.Chianti_version_main in ('8', '9', '10'):
             Splups = _chianti_tools.scupsRead(ion_chianti)
         elif pn.config.Chianti_version_main == '7':
             Splups = _chianti_tools.splupsRead(ion_chianti)
@@ -183,12 +181,7 @@ def Chianti_getOmega(ion_chianti, tem, lev1=None, lev2=None, Splups=None, NLevel
                     isplups = isplups[0]
                 ttype=Splups["ttype"][isplups]
                 cups=Splups["cups"][isplups]
-                if pn.config.Chianti_version_main == '9':
-                    nspl=Splups["ntemp"][isplups]
-                    dx=1./(float(nspl)-1.)
-                    xs = Splups['btemp'][isplups]
-                    splups=Splups["bscups"][isplups]
-                elif pn.config.Chianti_version_main == '8':
+                if pn.config.Chianti_version_main in ('8', '9', '10'):
                     nspl=Splups["ntemp"][isplups]
                     dx=1./(float(nspl)-1.)
                     xs = Splups['btemp'][isplups]
@@ -473,9 +466,7 @@ class _CollChianti(object):
         self._loadChianti()
         
     def _loadChianti(self):
-        if pn.config.Chianti_version_main == '9':
-            self.fullFileName = _chianti_tools.ion2filename(self.ion_chianti) + '.scups'
-        elif pn.config.Chianti_version_main == '8':
+        if pn.config.Chianti_version_main in ('8', '9', '10'):
             self.fullFileName = _chianti_tools.ion2filename(self.ion_chianti) + '.scups'
         elif pn.config.Chianti_version_main == '7':
             self.fullFileName = _chianti_tools.ion2filename(self.ion_chianti) + '.splups'
@@ -487,9 +478,7 @@ class _CollChianti(object):
         
         self.Chianti_version = self.collPath.split('/')[-4]
         self.comments = {}
-        if pn.config.Chianti_version_main == '9':
-            self.Splups = _chianti_tools.scupsRead(self.ion_chianti)
-        elif pn.config.Chianti_version_main == '8':
+        if pn.config.Chianti_version_main in ('8', '9', '10'):
             self.Splups = _chianti_tools.scupsRead(self.ion_chianti)
         elif pn.config.Chianti_version_main == '7':
             self.Splups = _chianti_tools.splupsRead(self.ion_chianti)
@@ -617,9 +606,7 @@ class _CollChianti(object):
         sources = []
         sources.append('Omega-values from {0}'.format(self.Chianti_version))
         
-        if pn.config.Chianti_version_main == '9':
-            refs = _chianti_tools.scupsRead(self.ion_chianti)
-        elif pn.config.Chianti_version_main == '8':
+        if pn.config.Chianti_version_main in ('8', '9','10'):
             refs = _chianti_tools.scupsRead(self.ion_chianti)
         elif pn.config.Chianti_version_main == '7':
             refs = _chianti_tools.splupsRead(self.ion_chianti)
